import QtQuick 1.0
import bb.cascades 1.4
import bb.cascades.pickers 1.0
import bb.system 1.2
import "Custom"
import timer 1.0
import bb.device 1.3

Sheet {
    onCreationCompleted: {
        if(playlistEditorOpened){sheet.destroy();}
        else{playlistEditorOpened=true; open();_playlist.updatePlaylistModel();}}
    
    
    Component.onDestruction: {playlistEditorOpened=false;}
    
    id: sheet
    attachedObjects:[
        
        SystemTimer{id:reTimer;interval:2000;onTimeout: {
                playListView.enabled=true;reTimer.stop();
        }},
        Connections {
            target: mainnav
            onClosePlaylistEditor:{sheet.close();sheet.destroy(1000)} 
        }
    ]
    
    
    Page { titleBar: TitleBar {
            appearance: TitleBarAppearance.Branded
            title: qsTr("Choose Playlist")
            
            dismissAction: ActionItem {
                title: qsTr("Close") 
                onTriggered: {sheet.close();sheet.destroy(1000)}
            }
        
    }
    actionBarVisibility: actionBarVisibility.Compact
    
    actions:[ 
        ActionItem {
            title:qsTr("Create Playlist")
            enabled:true
            ActionBar.placement: ActionBarPlacement.Signature
            imageSource: "asset:///images/ic_add.png"
            onTriggered: {
                incomingNewPlaylistAddition=true;creator.createQMLObject("PlaylistCreator.qml");
            }  
        }]
    Container {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        opacity: nightMode?0.8:1
        layout: DockLayout {}
        bottomPadding: 10
        Container {
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            Label {
                visible: _playlist.dataModell.size() === 0 ? true : false
                text: qsTr("No Playlists")
                textStyle.color: brightTheme? Color.Black: Color.White
                opacity: nightMode ? 0.6 : 0.8
                textStyle {
                    fontSize: FontSize.PointValue
                    fontSizeValue: 16
                    base: SystemDefaults.TextStyles.BigText
                }
            }
        }
        
        ListView {
            scrollRole: ScrollRole.Main
            
            id: playListView
            layout: StackListLayout { headerMode: ListHeaderMode.Sticky }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            dataModel: _playlist.dataModell
            function remove(indexPath) { _playlist.removeFromJson(indexPath);}
            
            
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Header {
                        title: _playlist.dataModell.size() + " " + qsTr("Item(s)")
                    }  
                },
                ListItemComponent {
                    
                    type: "item"
                    Container {
                        id: itemContainer
                        function bob(){diodelete.show();}
                        
                        PlaylistItem {
                            
                            
                            attachedObjects:[ 
                                
                                SystemDialog{
                                    id: diodelete
                                    title: qsTr("Delete")
                                    body: qsTr("Delete Playlist? (") +ListItemData.videoTitle + ")"
                                    buttonAreaLimit: 2
                                    confirmButton.label: qsTr("Yes")
                                    confirmButton.enabled: true
                                    cancelButton.label: qsTr("Cancel")
                                    cancelButton.enabled: true
                                    onFinished: {
                                        if(result == SystemUiResult.ConfirmButtonSelection) {remove(itemContainer.ListItem.view.remove(itemContainer.ListItem.indexPath))
                                            ; _playlist.updatePlaylistModel();
                                        }
                                        else if (result == SystemUiResult.CancelButtonSelection) {
                                            cancel();
                                        }
                                    }
                                }]
                            onQuickDeleteClicked: {
                                remove(itemContainer.ListItem.view.remove(itemContainer.ListItem.indexPath)); 
                                _playlist.updatePlaylistModel();
                            }
                            title: ListItemData.videoTitle
                            imageEnabled: false
                            // img:ListItemData.videoIconURL===""? "" :"file://"+ ListItemData.videoIconURL
                            
                            contextActions:   ActionSet {
                                title:  ListItemData.videoTitle
                                // subtitle: ListItemData.videoURL
                                actions:[
                                 
                                    DeleteActionItem{
                                        imageSource: "images/ic_delete.png"
                                        title:qsTr("Delete Playlist")
                                        onTriggered: {itemContainer.bob(); }
                                    }
                                ]
                            }
                        }
                    }
                }
            ]
            onTriggered: {
                playListView.enabled=false;
                reTimer.start();
                var data = _playlist.dataModell.data(indexPath);
             //   console.log(data.videoTitle)
             //   console.log(data.videoURL)
                playQueue.clear();

                playlistName= data.videoTitle;
                playlistURL= data.videoURL;
                incomingNewPlaylistAddition=true;
               openingPlaylist=true;
               creator.createQMLObject("PlaylistEdit.qml");
               sheet.close();
               sheet.destroy(1000)
            }
        
        }
    }
    }
}