import QtQuick 1.0
import bb.cascades 1.4
import bb.system 1.0

Sheet{
    id: sheet
Page {
    id:page
    titleBar: TitleBar {
        title:qsTr( "Favourites")
       
        dismissAction: ActionItem {
            title:qsTr( "Close")
            onTriggered: {
               sheet.close() 
            }
        }
        
    }
    attachedObjects: Connections{
        target: mainnav
        onCloseFavourites:{sheet.close();}
        
    }
    actionBarVisibility: ChromeVisibility.Compact
    actions: [
        ActionItem {
            imageSource: "asset:///images/ic_to_bottom.png"
            enabled:  view.dataModel.size() > 0? true: false
            title: qsTr("To Bottom")
            onTriggered: {
                var dataModelSize = view.dataModel.size(); // or listViewId.dataModel.childCount(0)
                if (dataModelSize > 0)
                {
                    var lastRowNumber = dataModelSize - 1
                    view.scrollToItem([0, lastRowNumber], ScrollAnimation.Default);
                }
            
            }  
        },
        ActionItem {
            title: qsTr("Delete All")
            imageSource: "images/ic_delete.png"
            ActionBar.placement: ActionBarPlacement.Signature
            enabled:_app.dataModel.childCount(0)===0? false: true
            onTriggered: {
                creator.createQMLObject("FavouritesDeleteAllDialog.qml");                
            }
        },
        ActionItem {
           imageSource: "asset:///images/ic_add_home.png"
           title: qsTr("Add Favourites to Home")
            ActionBar.placement: ActionBarPlacement.InOverflow
            onTriggered: {
                creator.createQMLObject("Custom/HSBookmarks.qml")
            }  }
    ]
    onCreationCompleted: {open();_app.updateDataModel(); console.log(_app.dataModel.size()) }   
    
    
    Container {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: DockLayout {}
        bottomPadding: 90
        Container {
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            Label {
                visible:_app.dataModel.childCount(0) === 0 ? true : false
                text: qsTr("No Favourites")
                textStyle.color:brightTheme? Color.Black:  Color.White
                opacity: nightMode ? 0.6 : 0.8
                textStyle {
                    fontSize: FontSize.PointValue
                    fontSizeValue: 16
                    base: SystemDefaults.TextStyles.BigText
                }
            }
        }
        ListView {
            scrollRole: ScrollRole.Main

            opacity: nightMode?0.8:1
            function remove(indexPath) { _app.removeFromJson(indexPath);}
            id: view
            dataModel: _app.dataModel
            scrollIndicatorMode: ScrollIndicatorMode.ProportionalBar
            onTriggered: {
                var data=dataModel.data(indexPath);
                
                if (data.favType === "Stream") {
                    audioSource = data.videoURL;
                    sourceStreamed = true;
                    streamTimer.start();
                } else if (data.favType === "InternetRadioStation") {
                    internetRadioSource = data.videoURL;
                    metaDataTitle = data.videoTitle;
                    internetRadioOpenDelay.start();
                } else {
                    audioSource = data.videoURL;
                    favPlay.start();
                }
                artWorkURI = data.videoIconURL;
                favouriteType = data.favType;
                activity.running = true;
                activity.visible = true;
                sheet.close();
                //_app.openFavourite(data.videoTitle, data.videoURL, data.videoIconURL, data.favType) 

            }
layout: StackListLayout {
    headerMode: ListHeaderMode.Sticky
}
            listItemComponents: [
                ListItemComponent {
                  type: "header"
                  Header {
                      title: _app.dataModel.size() + qsTr(" Favourite(s)")
                  }  
                },
                ListItemComponent {
                    type: "item"
                    
                    Container {
                        id: rootListItemContainer
                        property string pathIndex
                        property string title
                        property string urle
                        property string icon
                        function bob(){dio.show();}
                        function updateFav(indexPath, titlle, urrle, icone){
                            console.log(indexPath, titlle, urrle, icone)
                            pathIndex= indexPath.toString();
                            title= titlle;
                            urle= urrle;
                            icon= icone;
                            prompt.show();}
                        attachedObjects:[  SystemDialog{
                            id: dio
                            title: qsTr("Delete")
                            body:qsTr( "Delete Favourite? (") +ListItemData.videoTitle + ")"
                            buttonAreaLimit: 2
                            confirmButton.label: qsTr("Yes")
                            confirmButton.enabled: true
                            cancelButton.label: qsTr("Cancel")
                            cancelButton.enabled: true
                            onFinished: {
                                if(result == SystemUiResult.ConfirmButtonSelection) {remove(rootListItemContainer.ListItem.view.remove(rootListItemContainer.ListItem.indexPath))
                                }
                                else if (result == SystemUiResult.CancelButtonSelection) {
                                   dio.cancel();
                                }
                            }
                        }]
                    StandardListItem {
                        contextActions:   ActionSet {
                            title:  ListItemData.videoTitle
                            subtitle: ListItemData.videoURL
                            actions:[
                                DeleteActionItem{
                                imageSource: "images/ic_delete.png"
                                title:qsTr("Delete Favourite")
                                onTriggered: {rootListItemContainer.bob(); }
                            }]
                        }
                       
                     
                        title: ListItemData.videoTitle
                        description: ListItemData.videoURL
                        imageSource: ListItemData.videoIconURL
                        status: ListItemData.videoDuration
                      
                    }     
                                   
                }
                }
            ]
        }
    }
    
}
}
