import bb.cascades 1.4
import QtQuick 1.0
Sheet{
    id:sheet
    onCreationCompleted: {
        open();
    }
    property bool showingLyrics:false
    property bool fullscreen:false
    attachedObjects:[ Connections {
            target: mainnav
            onCloseLyrics:{ 
                console.log("Close requested")
                lyricsOpen=false;
                sheet.close();
            }
    }]
Page {
id:page

actionBarVisibility:fullscreen? ChromeVisibility.Hidden: showingLyrics? ChromeVisibility.Compact: ChromeVisibility.Hidden
    titleBar: TitleBar {
        visibility: fullscreen?  ChromeVisibility.Hidden: ChromeVisibility.Visible 
        title: showingLyrics? metaDataTitle +qsTr(" Lyrics"): qsTr("Local Lyrics")
        dismissAction: ActionItem {
            title: qsTr("Close")
            onTriggered: {
                sheet.close();
            }
        }
    }
    actions: [
        ActionItem {
            ActionBar.placement: ActionBarPlacement.Signature
            title:mediaPlaying? mediaPaused? qsTr("Play")  : qsTr("Pause") : qsTr("play")
            imageSource: mediaPlaying? mediaPaused? "images/ic_play.png" : "images/ic_pause.png" : "images/ic_play.png"
            onTriggered: {
                if(mediaPaused===true) playMedia()
                else pauseMedia();
            }
        },
        ActionItem {
            ActionBar.placement: ActionBarPlacement.InOverflow
            imageSource: "asset:///images/full_screen.png"
            title: qsTr("Fullscreen")
            onTriggered: {
                fullscreen=true;
                toast.showTextWithButton(qsTr("Double Tap Screen To Return"), qsTr("OK"), "lyricsFullscreenNotif")
            }
        },
        ActionItem {
            title: qsTr("Increase Font Size")
            ActionBar.placement: ActionBarPlacement.InOverflow
            imageSource: "asset:///images/ic_increase.png"
            onTriggered: {lyricsViewLabel.textStyle.fontSizeValue +=1}
        },
        ActionItem {
            enabled: lyricsViewLabel.textStyle.fontSizeValue<6?false:true
            title: qsTr("Decrease Font Size")
            ActionBar.placement: ActionBarPlacement.InOverflow
            imageSource: "asset:///images/ic_decrease.png"
            onTriggered: {lyricsViewLabel.textStyle.fontSizeValue-=1}
        },
        ActionItem {
            title: qsTr("Lyrics Settings")
            ActionBar.placement: ActionBarPlacement.InOverflow
            onTriggered: {
                creator.createQMLObject("LyricsSettings.qml")
            }  
        },
        ActionItem {
            id:nm
            title:qsTr("Night Mode")
            enabled: true
            imageSource:nightMode? "asset:///images/night_active.png":"asset:///images/night.png"
            ActionBar.placement:ActionBarPlacement.InOverflow
            onTriggered: { if(nightMode===true){nightMode=false;toast.showText(qsTr("Night Mode Disabled"))}
            else{nightMode=true;toast.showText(qsTr("Night Mode Enabled"))}
                nightModeChanged();page.addAction(nms)}
        },
        ActionItem {
            id:nms
            title:qsTr("Night Mode Settings")
            imageSource:""
            ActionBar.placement:ActionBarPlacement.InOverflow
            onCreationCompleted: {
                if(nightMode===false)page.removeAction(nms)
            }
            onTriggered: {creator.createQMLObject("NightModeSettings.qml")}
        }
    ]
    Container {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: DockLayout {
            
        }
        Container {
            id: lyricsView
            opacity: 0
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            ScrollView{
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                
                Container {
                    opacity: nightMode? 0.8:1
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    topPadding: 5
                    leftPadding: 5
                    rightPadding: 5
                    bottomPadding: 70
                    gestureHandlers: DoubleTapHandler {
                        onDoubleTapped: {
                            fullscreen=false;
                        }
                    }
                    Label {
                        id: lyricsViewLabel
                        text:  fileSystemLyrics
                        multiline: true
                        textStyle.fontSize: FontSize.PointValue
                        textStyle.fontSizeValue: 8

                    }
                }
            }
        }
      Container {
          id: img
          opacity: nightMode?0.8:1
          horizontalAlignment: HorizontalAlignment.Center
          verticalAlignment: VerticalAlignment.Center
          bottomPadding: 220
          ImageView {
              imageSource: "asset:///images/search_blue.png"
          }
      }
      Container {
          id: text
          opacity: nightMode?0.8:1
          horizontalAlignment: HorizontalAlignment.Center
          verticalAlignment: VerticalAlignment.Bottom
          bottomPadding:miniSquareDevice?50: 370
          Label{
              multiline: true
              textStyle.fontSize: FontSize.PointValue
              textStyle.fontSizeValue: 8
              text: qsTr("We found a file which may contain Lyrics for '") + metaDataTitle + qsTr("', would you like to take a look?")
          }
      }  
      Container {
          horizontalAlignment: HorizontalAlignment.Center
          verticalAlignment: VerticalAlignment.Bottom
          bottomPadding: 10
          opacity: nightMode?0.8:1
          id: button
          Button {
              color: Color.create(getAppColour())
              text: qsTr("Show Lyrics")
              onClicked: {
                  img.opacity=0;
                  button.opacity=0;
                  text.opacity=0;
                  lyricsView.opacity= nightMode? 0.8:1;
                  showingLyrics=true;
                  
              }
          }
      }
     
    }
}
}