import QtQuick 1.0
import timer 1.0
import bb.system 1.2
import bb.cascades 1.4
Sheet {
    id: sheet
    property bool alternatives:false
    onCreationCompleted: {
        alternativeCheck();sheet.open();autoStationDownloadTimer.start();
    }
    onClosed: { _app.deleteFile(_app.homePath() + "/AlternativeStationsEnabledCheck.txt"); }
    function alternativeCheck(){
        downloadManager.silentMode=true;
        downloadManager.download("http://legacy.allstarsoftware.co.uk/StarPlayerBB10/InternetRadio/AlternativeStationsEnabledCheck.txt", _app.homePath() + "/AlternativeStationsEnabledCheck.txt")
    }
    property string offlineModelURL
    attachedObjects:[ 
        Connections{target: downloadManager; onDownloadComplete:{if(downloadManager.silentMode===true){  
                    downloadManager.silentMode=false;alternatives= _app.checkRemoteFeature(_app.homePath() + "/AlternativeStationsEnabledCheck.txt");
                    if(alternatives===false){group.remove(option9);}        
        }}
    },
        Connections{
        target: mainnav
        onUpdateInternetCountryList:{option2.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelUK.xml"); 
            option3.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelGermany.xml") 
            option4.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelFrance.xml") 
            option5.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelSpain.xml") 
            option6.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelCanada.xml")
            option7.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelItalian.xml")
            option9.enabled=_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelAlternative.xml") }


        onCloseInternetRadioList:{sheet.close();}
        onInternetRadioModelDownloadCompleted:{modelURL="";}
    },
    SystemTimer{
        id: autoStationDownloadTimer; interval: 600; onTimeout: {autoStationDownloadTimer.stop();
            if(_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelUK.xml")===false){creator.createQMLObject("InternetRadioModelDownloader.qml");updateInternetStations();}
        }
        
    }
]
Page {   
    actions: [
        ActionItem {
          title: "Add Custom Radio Station"  
          imageSource: "images/ic_add.png"
          onTriggered: {
              creator.createQMLObject("AddCustomRadioStation.qml")
          }
        },
        
        ActionItem {
            title:  qsTr("Update")
            enabled: stationUpdateCount<5?true:false
            imageSource: "images/ic_reload.png"
            ActionBar.placement: ActionBarPlacement.Signature
            onTriggered: {stationUpdateCount+=1; creator.createQMLObject("InternetRadioModelDownloader.qml");updateInternetStations();}
        },
        ActionItem {
            title:  qsTr("Back")
          imageSource: "images/ic_previous.png"
          ActionBar.placement: ActionBarPlacement.OnBar
          onTriggered: {
              sheet.close();
          }  
        },
        ActionItem {
            title: "Scheduled Recording"  
            ActionBar.placement: ActionBarPlacement.OnBar

            imageSource: internetRadioScheduledRecording? "images/sched_active.png":"images/sched.png"
            onTriggered: {
                creator.createQMLObject("ScheduledRecording.qml");
            }
        },
        ActionItem {
            title:  qsTr("Add to Homescreen")
            enabled: true
            imageSource: "images/ic_add_home.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            onTriggered: {creator.createQMLObject("Custom/HSInternetRadio.qml")}
        },
        ActionItem {
            title:  qsTr("Use Custom URL")
          imageSource: "asset:///images/ic_browser.png"
    ActionBar.placement: ActionBarPlacement.OnBar
    onTriggered: {
        creator.createQMLObject("InternetRadioStreamURLInput.qml")}
    
        },
        ActionItem {
            title:  qsTr("Internet Radio Settings")
          onTriggered: {
creator.createQMLObject("InternetRadioSettings.qml") }  
        }
     
    
    ]
    titleBar: TitleBar {
        id: titleBar
        kind: TitleBarKind.FreeForm
        property bool topOpened
        kindProperties: FreeFormTitleBarKindProperties {
            
            Container {
                layout: DockLayout {   
                }
              
                Container {
                
                 horizontalAlignment: HorizontalAlignment.Center
                 verticalAlignment: VerticalAlignment.Center
                 leftPadding: 20
                
                Label {
                    text:  qsTr("Internet Radio BETA")
                    textStyle.fontSize: FontSize.Large
                    textStyle.fontWeight: FontWeight.Bold
                }
            }
            }
            expandableArea {
                onExpandedChanged: {
               if(expanded)titleBar.topOpened=true
               else titleBar.topOpened=false
           }     
                content: RadioGroup {
                    id: group
                    onSelectedValueChanged: {
                        titleBar.topOpened=false;
                        
                        
                        if(selectedIndex===0){stationListHeaderName="Custom Stations";
                        customStationsView=true;
                        }
                        else{
                            customStationsView=false;
                            modelURL= selectedValue;
                            if(selectedIndex===1)stationListHeaderName="Alternative";
                        else if(selectedIndex===2)stationListHeaderName="UK";
                        else if(selectedIndex===3)stationListHeaderName="German";
                        else if(selectedIndex===4)stationListHeaderName="French";
                        else if(selectedIndex===5)stationListHeaderName="Spanish";
                        else if(selectedIndex===6)stationListHeaderName="Canadian";
                        else if(selectedIndex===7)stationListHeaderName="Italian";
                    }
                        countryLabel.visible=false;
                    }
                    onCreationCompleted: {
                        var bob= appsettings.getSystemSetting("DefaultRadioListCountry", "")
                        if(bob==="Last Selected Country"){selectedIndex=parseInt(appsettings.getSystemSetting("RadioLastSelectedCountry", ""))}
                        else if(bob==="Custom Stations"){selectedIndex=0;}
                        else if(bob==="Alternative Stations"){selectedIndex=1;}
                        else if(bob==="UK Stations"){selectedIndex=2;}
                        else if(bob==="German Stations"){selectedIndex=3;}
                        else if(bob==="French Stations"){selectedIndex=4;}
                        else if(bob==="Spanish Stations"){selectedIndex=5;}
                        else if(bob==="Canadian Stations"){selectedIndex=6;}
                        else if(bob==="Italian Stations"){selectedIndex=7;}

                    }
                    onSelectedIndexChanged: {
                        if(appsettings.getSystemSetting("DefaultRadioListCountry", "")==="Last Selected Country"){
                        appsettings.saveSystemSetting("RadioLastSelectedCountry", selectedIndex);}
                        else if(selectedIndex===0){_customStations.updateHistoryDataModel()}
                    }                   
                    Option {id: option1; enabled:true;text: "Custom Stations";  value: "custom" }
                    Option {id: option9; enabled:true;text: "Alternative Stations";  value:"file://" +_app.homePath()+"/InternetRadioStationsModelAlternative.xml" }
                    Option {id: option2; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelUK.xml" )  ;text: "UK Stations";  value: "file://" +_app.homePath()+"/InternetRadioStationsModelUK.xml" }
                    Option { id: option3; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelGermany.xml" )  ;text: "German Stations" ;value: "file://" +_app.homePath()+"/InternetRadioStationsModelGermany.xml" }
                    Option { id: option4; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelFrance.xml" )  ;text: "French Stations" ;value: "file://" +_app.homePath()+"/InternetRadioStationsModelFrance.xml" }
                    Option { id: option5; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelSpain.xml" )  ;text: "Spanish Stations";value: "file://" +_app.homePath()+"/InternetRadioStationsModelSpain.xml"  }
                    Option { id: option6; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelCanada.xml" )  ;text: "Canadian Stations"; value: "file://" +_app.homePath()+"/InternetRadioStationsModelCanada.xml" }
                    Option { id: option7; enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelItalian.xml" )  ;text: "Italian Stations"; value: "file://" +_app.homePath()+"/InternetRadioStationsModelItalian.xml" }
                   // Option { id: option8;enabled:_app.checkFileExists(_app.homePath()+"/InternetRadioStationsModelUS.xml" )  ; text: "US Stations" ;value:"file://" +_app.homePath()+ "/InternetRadioStationsModelUS.xml" }
                    dividersVisible: true

                }
                indicatorVisibility: TitleBarExpandableAreaIndicatorVisibility.Visible
                expanded: titleBar.topOpened
                
            }
        }
    }
    Container {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: DockLayout {
            
        }
        Container {
            id: labelConte
            visible:customStationsView?false: modelURL===""?true:false
            opacity:titleBar.topOpened?0:1
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            Label {
                id: countryLabel
                visible:true
                multiline: true
                text: qsTr( "Choose a Country Above\nor add a Custom Station")
                textStyle.color: brightTheme? Color.Black:Color.White
                opacity: nightMode ? 0.6 : 0.8
                textStyle {
                    fontSize: FontSize.PointValue
                    fontSizeValue: 14
                    base: SystemDefaults.TextStyles.BigText
                }
            }
        }

        ListView{
            id: view
            dataModel: _customStations.dataModel
            opacity: customStationsView?nightMode?0.8:1:0

            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            scrollRole: ScrollRole.Main
            function remove(indexPath) { _customStations.removeFromJson(indexPath);}

            function sched(title, url){console.log("Recieved"+ title + url); scheduledRecModelStationURL=url; scheduledRecModelStationName=title; creator.createQMLObject("ScheduledRecording.qml")}
            scrollIndicatorMode: ScrollIndicatorMode.ProportionalBar
            layout: StackListLayout {
                headerMode: ListHeaderMode.Sticky
            }
            onTriggered: {
                
                var data = _customStations.dataModel.data(indexPath);
                if(data.url===""){}
                else{ _app.openInternetRadioStation(data.url, data.title, data.image, data.backupUrl, data.comments, data.image, data.bitrate, data.fileFormat);
            }
            }
            
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Header {visible: false}  
                },
                
                ListItemComponent {
                    type: "item"
                    
                    Container {
                        id: rootListItemContainerr
                        property string pathIndex
                        property string title
                        property string urle
                        property string icon
                        function bob(){dio.show();}
                        
                        attachedObjects:[  SystemDialog{
                                id: dio
                                title: qsTr("Remove")
                                body: qsTr("Remove Custom Radio Station? (" )  +ListItemData.title + ")"
                                buttonAreaLimit: 2
                                confirmButton.label: qsTr("Yes")
                                confirmButton.enabled: true
                                cancelButton.label: qsTr("Cancel")
                                cancelButton.enabled: true
                                onFinished: {
                                    if(result == SystemUiResult.ConfirmButtonSelection) {remove(rootListItemContainerr.ListItem.view.remove(rootListItemContainerr.ListItem.indexPath))
                                    }
                                    else if (result == SystemUiResult.CancelButtonSelection) {
                                        close();
                                    }
                                }
                        }]
                    StandardListItem {
                        contextActions:   ActionSet {
                            title:  ListItemData.title
                            subtitle: ListItemData.url
                            actions:[
                                ActionItem{
                                    imageSource: "images/sched.png"
                                    title:qsTr("Schedule Recording")
                                    onTriggered: {rootListItemContainerr.ListItem.view.sched(ListItemData.title, ListItemData.url); }
                                },
                                DeleteActionItem {
                                    imageSource: "images/ic_delete.png"
                                    title:qsTr("Remove Radio Station")
                                    onTriggered: {rootListItemContainerr.bob(); }
                                }
                            ]
                        }
                        title: ListItemData.title
                        description: ListItemData.url
                    }     
                
                    }
                }
            ]
        }
        ListView {
            id: listView
            opacity: customStationsView?0:1
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            scrollRole: ScrollRole.Main
            function sched(title, url){console.log("Recieved"+ title + url); scheduledRecModelStationURL=url; scheduledRecModelStationName=title; creator.createQMLObject("ScheduledRecording.qml")}
            layout: StackListLayout {
                headerMode: ListHeaderMode.Sticky
            }
            dataModel: XmlDataModel {
                id: modelr
                source: modelURL
            }
            onTriggered: {
                var data=dataModel.data(indexPath)
                if(data.url===""){}
                else{
                _app.openInternetRadioStation(data.url, data.title, data.image, data.backupUrl, data.comments, data.image, data.bitrate, data.fileFormat);
                console.log(data.url, data.title,  data.image, data.backupUrl, data.comments, data.image, data.bitrate, data.fileFormat);}

            }
            
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Header {
                        title:""
                    }  
                },
                ListItemComponent {
                    type: "item"
                    
                    Container {
                        id: rootListItemContainer

                    StandardListItem {
                        contextActions:   ActionSet {
                            title:  ListItemData.title
                            actions:[
                               ActionItem{
                                    imageSource: "images/sched.png"
                                    title:qsTr("Schedule Recording")
                                    onTriggered: {rootListItemContainer.ListItem.view.sched(ListItemData.title, ListItemData.url); }
                                },
                               ActionItem {
                                   title: "Use Alternative Stream"
                                   enabled: ListItemData.backupUrl===""?false:true
                                   imageSource: "images/internet_radio_icon.png"
                                   onTriggered: {
                                       if(ListItemData.url===""){}
                                       else{
                                           _app.openInternetRadioStation(ListItemData.backupUrl, ListItemData.title, ListItemData.image, ListItemData.backupUrl, ListItemData.comments, ListItemData.image, ListItemData.bitrate, ListItemData.fileFormat);
                                           console.log(ListItemData.url, ListItemData.title,  ListItemData.image, ListItemData.backupUrl, ListItemData.comments, ListItemData.image, ListItemData.bitrate, ListItemData.fileFormat);}
                                   }
                               }
                            ]
                        }
                        title: ListItemData.title
                        description: ListItemData.comments
                        status: ListItemData.bitrate
                        
                    }     
                
                    }
                }
            ]
        }
    }
}

}