import QtQuick 1.0
import bb.cascades 1.4
import bb.cascades.pickers 1.0
import bb.system 1.2
import timer 1.0
import "Custom"
import bb.device 1.3

Sheet {
    onCreationCompleted: {
        if(playlistEditorOpened){sheet.destroy();}
        else{playlistEditorOpened=true; open();_playlist.updatePlaylistModel();}}
    
    Component.onDestruction: {playlistEditorOpened=false;}
    
    id: sheet
    attachedObjects:[
        
        SystemTimer{id:reTimer;interval:2000;onTimeout: {
                playListView.enabled=true;reTimer.stop();
        }},
Connections {
  target: mainnav
  onClosePlaylistEditor:{sheet.close();sheet.destroy(1000)} 
},
        
     
    ComponentDefinition {
        id: deleteAllDio
        content:SystemDialog{
            id: dio
            Component.onCompleted: {
                show();
            }
            title: qsTr("Delete All?")
            body:qsTr( "Delete All Playlists?")
            buttonAreaLimit: 2
            confirmButton.label: qsTr("Yes")
            confirmButton.enabled: true
            cancelButton.label: qsTr("Cancel")
            cancelButton.enabled: true
            onFinished: {
                if(result == SystemUiResult.ConfirmButtonSelection) {  _playlist.clearJsonFile();
                    _playlist.updatePlaylistModel(); _app.removeDir(_app.homePath()+"/Playlists") }
                else if (result == SystemUiResult.CancelButtonSelection) {
                    cancel();
                }
            }
        }
    },
    ComponentDefinition {
        id: pickerPlaylist
        content: FilePicker {
            id: filePicker1
            Component.onCompleted: {open();}
            type: FileType.Music
            mode: FilePickerMode.Picker
            property string bob
            title:  qsTr("Select Playlist")
            directories: [ path]
            filter: FileType.Music
            onFileSelected: {
                if(getFileType(selectedFiles[0].toString())==="m3u"){canceled();importSource=selectedFiles[0].toString(); playlistM3uImporting=true;creator.createQMLObject("PlaylistCreator.qml")}
                
            }
        }
    }
]
    
   
Page { titleBar: TitleBar {
        appearance: TitleBarAppearance.Branded
        title: qsTr("Playlists")
        
        dismissAction: ActionItem {
            title: qsTr("Close") 
            onTriggered: {sheet.close();sheet.destroy(1000)}
        }
    
}
actionBarVisibility: actionBarVisibility.Compact

actions:[ 

ActionItem {
    title:qsTr("Create Playlist")
    enabled:true
    ActionBar.placement: ActionBarPlacement.Signature
    imageSource: "asset:///images/ic_add.png"
    onTriggered: {
     creator.createQMLObject("PlaylistCreator.qml")
    }  
},
ActionItem {
  title: "Import Playlist"
  onTriggered: {pickerPlaylist.createObject();}  
  ActionBar.placement: ActionBarPlacement.OnBar
  imageSource: "images/import.png"
},
DeleteActionItem {
    title: qsTr("Delete All Playlists")
  enabled: playListView.dataModel.size() <1?false:true
  onTriggered: {deleteAllDio.createObject();}  
}]
    Container {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        opacity: nightMode?0.8:1
        layout: DockLayout {}
        bottomPadding: 10
        Container {
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            Label {
                visible: _playlist.dataModell.size() === 0 ? true : false
                text: qsTr("No Playlists")
                textStyle.color: brightTheme? Color.Black: Color.White
                opacity: nightMode ? 0.6 : 0.8
                textStyle {
                    fontSize: FontSize.PointValue
                    fontSizeValue: 16
                    base: SystemDefaults.TextStyles.BigText
                }
            }
        }
        
        ListView {
            scrollRole: ScrollRole.Main

            id: playListView
            layout: StackListLayout { headerMode: ListHeaderMode.Sticky }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            dataModel: _playlist.dataModell
            function remove(indexPath) { _playlist.removeFromJson(indexPath);}
           
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Header {
                        title: _playlist.dataModell.size() + " " + qsTr("Playlists(s)")
                    }  
                },
                ListItemComponent {
                    
                    type: "item"
                    Container {
                        id: itemContainer
                        
                        function bob(){diodelete.show();}
                        function exportPlaylist(){exportDialog.createObject();}


                        PlaylistItem {
                            
                        
                            attachedObjects:[ 
                                ComponentDefinition {
                                    id: exportDialog
                                    content: SystemListDialog {
                                        id: listDialog
                                        Component.onCompleted: {
                                            listDialog.appendItem(qsTr("Internal Memory"))
                                            if(_app.checkSDCard()===true){listDialog.appendItem(qsTr("SD Card"))}
                                            listDialog.se
                                            listDialog.show();
                                        }
                                        title: qsTr("Choose Export Location")
                                        confirmButton.label:qsTr( "Choose")
                                        cancelButton.label: qsTr("Cancel")
                                        selectionIndicator: selectionIndicator.Highlight
                                        
                                        onFinished: {
                                            if (result == SystemUiResult.ConfirmButtonSelection) {
                                                console.log(selectedIndices)
                                                if(selectedIndices==0){_app.copyFile(ListItemData.videoURL, "/accounts/1000/shared/music/"+ListItemData.videoTitle+ ".m3u");_app.showGlobalToast("Playlist Exported to: Device Memory/Music")}
                                                else if(selectedIndices==1){_app.copyFile(ListItemData.videoURL, "/accounts/1000/removable/sdcard/Music/"+ListItemData.videoTitle+ ".m3u");_app.showGlobalToast("Playlist Exported to: SD Card/music")}
                                            
                                            
                                            }
                                            else{listDialog.cancel();}
                                        }
                                    }
                                
                                },
                                SystemDialog{
                                    id: diodelete
                                    title: qsTr("Delete")
                                    body: qsTr("Delete Playlist? (") +ListItemData.videoTitle + ")"
                                    buttonAreaLimit: 2
                                    confirmButton.label: qsTr("Yes")
                                    confirmButton.enabled: true
                                    cancelButton.label: qsTr("Cancel")
                                    cancelButton.enabled: true
                                    onFinished: {
                                        if(result == SystemUiResult.ConfirmButtonSelection) {_app.deleteFile(ListItemData.videoURL);remove(itemContainer.ListItem.view.remove(itemContainer.ListItem.indexPath))
                                             _playlist.updatePlaylistModel();
                                        }
                                        else if (result == SystemUiResult.CancelButtonSelection) {
                                            cancel();
                                        }
                                    }
                            }]
                            allowQuickDelete: false
                            title: ListItemData.videoTitle
                            imageEnabled: false
                           // img:ListItemData.videoIconURL===""? "" :"file://"+ ListItemData.videoIconURL

                            contextActions:   ActionSet {
                                title:  ListItemData.videoTitle
                               // subtitle: ListItemData.videoURL
                                actions:[
                                    ActionItem {
                                      enabled: _app.checkSharedFiles()
                                      title: "Export Playlist"
                                      imageSource:"images/export.png"
                                      onTriggered: {
                                          itemContainer.exportPlaylist();
                                        
                                      }  
                                    },
                                    DeleteActionItem{
                                        imageSource: "images/ic_delete.png"
                                        title:qsTr("Delete Playlist")
                                        onTriggered: {itemContainer.bob(); }
                                    }
                                ]
                            }
                        }
                    }
                }
            ]
            onTriggered: {

            playListView.enabled=false;
            reTimer.start();
            playQueue.clear();
              var data = _playlist.dataModell.data(indexPath);
          
              incomingNewPlaylistAddition=false;
             // console.log(data.videoTitle)
             // console.log(data.videoURL)
              playlistName= data.videoTitle;
              playlistURL= data.videoURL;
              openingPlaylist=true;
              creator.createQMLObject("PlaylistViewer.qml")
            }
            
        }
    }
}
}