import QtQuick 1.0
import bb.cascades 1.4
import bb.system 1.0

Sheet{
    id: sheet
    Page {
        id:page
        titleBar: TitleBar {
            title:qsTr( "Last Played")
            
            dismissAction: ActionItem {
                title: qsTr("Close")
                onTriggered: {
                    sheet.close() 
                }
            }
        
        }
        attachedObjects: Connections {
            target: mainnav 
            onCloseHistory:{sheet.close();}
        }
        actionBarVisibility: ChromeVisibility.Compact

      
        actions: [
            ActionItem {
                imageSource: "asset:///images/ic_to_top.png"
                enabled:  view.dataModel.size() > 0? true: false
                title: qsTr("To Top")
                onTriggered: {view.scrollToItem(_recentlyPlayed.dataModel.first());
            
                }  
            },
            ActionItem {
                title: qsTr("Delete All")
                imageSource: "images/ic_delete.png"
                ActionBar.placement: ActionBarPlacement.Signature
                enabled:_recentlyPlayed.dataModel.childCount(0)===0? false: true
                onTriggered: {
                    creator.createQMLObject("RecentlyPlayedDeleteAllDialog.qml");                
                }
            },
            ActionItem {
                imageSource: "asset:///images/ic_add_home.png"
                title:qsTr( "Add Last Played to Home")
                ActionBar.placement: ActionBarPlacement.InOverflow
                onTriggered: {
                    creator.createQMLObject("Custom/HSLastPlayed.qml")
                }  }
        ]
        onCreationCompleted: { open(); _recentlyPlayed.updateHistoryDataModel(); console.log(_recentlyPlayed.dataModel.childCount(0));view.scrollToItem(_recentlyPlayed.dataModel.last(), ScrollAnimation.Smooth); }   
        
        
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            layout: DockLayout {}
            bottomPadding: 90
            Container {
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                Label {
                    visible:_recentlyPlayed.dataModel.childCount(0) === 0 ? true : false
                    text: qsTr("No Last Played")
                    textStyle.color: brightTheme? Color.Black: Color.White
                    opacity: nightMode ? 0.6 : 0.8
                    textStyle {
                        fontSize: FontSize.PointValue
                        fontSizeValue: 16
                        base: SystemDefaults.TextStyles.BigText
                    }
                }
            }
            ListView {
                opacity: nightMode?0.8:1
                scrollRole: ScrollRole.Main

                function remove(indexPath) { _recentlyPlayed.removeFromJson(indexPath);}
                id: view
           
                dataModel: _recentlyPlayed.dataModel
                scrollIndicatorMode: ScrollIndicatorMode.ProportionalBar
                layout: StackListLayout {
                    headerMode: ListHeaderMode.Sticky
                }
                listItemComponents: [
                    ListItemComponent {
                        type: "header"
                        Header {
                            visible: false
                        }  
                    },
                    
                    ListItemComponent {
                        type: "item"
                        
                        Container {
                            id: rootListItemContainer
                            property string pathIndex
                            property string title
                            property string urle
                            property string icon
                            function bob(){dio.show();}

                            attachedObjects:[  SystemDialog{
                                    id: dio
                                    title: qsTr("Remove")
                                    body: qsTr("Remove Last Played Item? (" )  +ListItemData.videoTitle + ")"
                                    buttonAreaLimit: 2
                                    confirmButton.label: qsTr("Yes")
                                    confirmButton.enabled: true
                                    cancelButton.label: qsTr("Cancel")
                                    cancelButton.enabled: true
                                    onFinished: {
                                        if(result == SystemUiResult.ConfirmButtonSelection) {remove(rootListItemContainer.ListItem.view.remove(rootListItemContainer.ListItem.indexPath))
                                        }
                                        else if (result == SystemUiResult.CancelButtonSelection) {
                                            close();
                                        }
                                    }
                            }]
                        StandardListItem {
                            contextActions:   ActionSet {
                                title:  ListItemData.videoTitle
                                subtitle: ListItemData.videoURL
                                actions:[
                                    DeleteActionItem {
                                        imageSource: "images/ic_delete.png"
                                        title:qsTr("Remove Last Played")
                                        onTriggered: {rootListItemContainer.bob(); }
                                    }
                                ]
                            }
                            gestureHandlers: TapHandler {
                                onTapped: {_recentlyPlayed.openHistoryVideo(ListItemData.videoURL, ListItemData.videoIconURL, ListItemData.itemType);}
                                
                            }
                           
                            title: ListItemData.videoTitle
                            description: ListItemData.videoURL
                            status: ListItemData.videoDuration
                            imageSource: ListItemData.videoIconURL
                        
                        }     
                    
                        }
                    }
                ]
            }
        }
    
    }
}
