import QtQuick 1.0
import bb.cascades 1.4
import timer 1.0

Sheet {
    id: tutorialSheet
    peekEnabled: false
    onCreationCompleted: {  open();}
    onOpened: {
        listView.scrollToItem([0], ScrollAnimation.Smooth)
    }
    
    attachedObjects:[Connections {
            target:orientationH
            onOrientationAboutToChange:{tutorialContainer.opacity=0;}
            onOrientationChanged:{reOpacity.start();}
    },
    Connections {
        target: _app
        onRequestHelpPage:{console.log(help); appsettings.saveSystemSetting("webStreamTut", "true"); if(help==="streaming") tutorialSheet.close(); creator.createQMLObject("Help/WebStream.qml")}
    },
    SystemTimer{
        id: reOpacity
        interval: 300
        onTimeout: {
            reOpacity.stop();
            tutorialContainer.opacity=nightMode?0.8:1;
        }
    }
]


Page {
    id: tutorialPage
    titleBar: TitleBar {
        id: titleBar
        title: qsTr("Web Streaming")
        acceptAction: ActionItem {
            title: tutorialPage.pageShown == 3 ? qsTr("Done") : qsTr("Next")
            onTriggered: {
                if (tutorialPage.pageShown == 3) {
                    appsettings.saveSystemSetting("webStreamTut", "true");
                    tutorialSheet.close();
                    creator.createQMLObject("StreamSource.qml");
                }
                else 
                    listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
            }
        }

    }
    
    property int pageShown
    
    Container {
        opacity: nightMode?0.8:1.0
        id: tutorialContainer
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        background: brightTheme? Color.White: Color.Black
        ListView {
            id: listView
            scrollRole: ScrollRole.Main

            property int deviceWidth:  pixelWidth==""? originalPixelWidth: pixelWidth
            property int deviceHeight: pixelHeight==""? originalPixelHeight: pixelHeight
            
            property variant background: tutorialContainer.background
            
            dataModel: XmlDataModel { source: "asset:///streamTutorialModel.xml" }
            layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
            flickMode: FlickMode.SingleItem
            
            function updatePageShown(page) {
                tutorialPage.pageShown = page
            }
            
            listItemComponents: [
                ListItemComponent {
                    type: "item"
                    Container {
                        id: itemContainer
                        layout: DockLayout {}
                        preferredWidth: itemContainer.ListItem.view.deviceWidth
                        preferredHeight: itemContainer.ListItem.view.deviceHeight
                        attachedObjects: LayoutUpdateHandler {
                            id: luhPosition
                            onLayoutFrameChanged: {
                                if (luhPosition.layoutFrame.x >= - itemContainer.preferredWidth / 2 && luhPosition.layoutFrame.x <= itemContainer.preferredWidth / 2) {
                                    itemContainer.ListItem.view.updatePageShown(ListItemData.page)
                                } 
                            }
                        }
                        Container {
                            layout: DockLayout {}
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Fill
                            ImageView {
                                imageSource: ListItemData.image
                                filterColor: Application.themeSupport.theme.colorTheme.style == VisualStyle.Bright? Color.Black: undefined

                                horizontalAlignment: HorizontalAlignment.Center
                                verticalAlignment: VerticalAlignment.Center
                                maxHeight: itemContainer.ListItem.view.deviceHeight * 0.7
                                maxWidth: itemContainer.ListItem.view.deviceWidth * 0.7
                                scalingMethod: ScalingMethod.AspectFit
                            }
                            Container {
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Top
                                opacity: 1
                                background: itemContainer.ListItem.view.background
                                Label {
                                    text: ListItemData.description
                                    multiline: true
                                    horizontalAlignment: HorizontalAlignment.Center
                                    textStyle{
                                        color:Application.themeSupport.theme.colorTheme.style == VisualStyle.Bright? Color.Black: Color.White
                                        fontSize: FontSize.PointValue
                                        fontSizeValue: 10
                                        base: SystemDefaults.TextStyles.TitleText     
                                    }  
                                }
                            }
                            Container {
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Bottom
                                bottomPadding: 5
                                leftPadding: 2
                                rightPadding: 2
                                opacity: 1
                                background: itemContainer.ListItem.view.background
                                gestureHandlers: TapHandler {
                                    onTapped: {
                                        if(ListItemData.page==="2"){
                                        _app.openHelpPage("streaming");}
                                    }
                                }
                                Label {
                                    text: ListItemData.subTitle
                                    multiline: true
                                    horizontalAlignment: HorizontalAlignment.Center
                                    textStyle{
                                        color: ListItemData.page==="2"? Color.create("#0092cc"): Application.themeSupport.theme.colorTheme.style == VisualStyle.Bright? Color.Black: Color.White

                                        fontSize: FontSize.PointValue
                                        fontWeight: ListItemData.page==="2"? FontWeight.Bold: FontWeight.Normal
                                        fontSizeValue: ListItemData.page==="2"? 8:7 
                                        base: SystemDefaults.TextStyles.BodyText     
                                    }  
                                }
                            }
                        }
                    }
                }
            ]    
        }
    }
}
}