import QtQuick 1.0
import bb.cascades 1.2

import timer 1.0

Sheet {
    id: tutorialSheet
    peekEnabled: false
    onCreationCompleted: {  open();}
    onOpened: {
        listView.scrollToItem([0], ScrollAnimation.Smooth)
    }
  
    attachedObjects:[Connections {
        target:orientationH
        onOrientationAboutToChange:{tutorialContainer.opacity=0;}
        onOrientationChanged:{reOpacity.start();}
    },
    SystemTimer{
        id: reOpacity
        interval: 300
        onTimeout: {
            reOpacity.stop();
            tutorialContainer.opacity=1;
        }
    }
    ]
    
    
    Page {
       
        id: tutorialPage
        titleBar: TitleBar {
            id: titleBar
          
            title: qsTr("Welcome")
            acceptAction: ActionItem {
                title: tutorialPage.pageShown == 9 ? qsTr("Done") : qsTr("Next")
                onTriggered: {
                    if (tutorialPage.pageShown == 9) {
                        
                 appsettings.saveSystemSetting("firstRun", "true");
                 appsettings.saveSystemSetting("AnnouncementUpdatePopup", "true");
                 appsettings.saveSystemSetting("albumArtActiveFrame", "true");
                        tutorialSheet.close();
                        welcomeScreen();
                        firstRun=true;
                    }
                    else 
                        listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
                }
            }
            /*dismissAction: ActionItem {
                title: qsTr("Dismiss")
                onTriggered: {
                    tutorialSheet.close()
                }
            }*/
        }
        
        property int pageShown
      
        Container {
            id: tutorialContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            background: Color.Black
            ListView {
                id: listView
                property bool listScrolling:false
                property int deviceWidth:  pixelWidth==""? originalPixelWidth: pixelWidth
                property int deviceHeight: pixelHeight==""? originalPixelHeight: pixelHeight
                scrollRole: ScrollRole.Main

                property variant background: tutorialContainer.background
                
                dataModel: XmlDataModel { source: "asset:///tutorialModel.xml" }
                layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
                flickMode: FlickMode.SingleItem
                
                function updatePageShown(page) {
                    tutorialPage.pageShown = page
                }
                attachedObjects: ListScrollStateHandler {
                    id: scrollStateHandler
                    
                    onScrollingChanged: {
                        if(scrolling)listView.listScrolling=true 
                        else listView.listScrolling=false
                    }
                }
                
                listItemComponents: [
                    ListItemComponent {
                        type: "item"
                        Container {
                            id: itemContainer
                            layout: DockLayout {}
                            preferredWidth: itemContainer.ListItem.view.deviceWidth
                            preferredHeight: itemContainer.ListItem.view.deviceHeight
                            attachedObjects: LayoutUpdateHandler {
                                id: luhPosition
                                onLayoutFrameChanged: {
                                    if (luhPosition.layoutFrame.x >= - itemContainer.preferredWidth / 2 && luhPosition.layoutFrame.x <= itemContainer.preferredWidth / 2) {
                                        itemContainer.ListItem.view.updatePageShown(ListItemData.page)
                                    } 
                                }
                            }
                            Container {
                                layout: DockLayout {}
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                ImageView {
                                    imageSource: ListItemData.image
                                    horizontalAlignment: HorizontalAlignment.Center
                                    verticalAlignment: VerticalAlignment.Center
                                    maxHeight: itemContainer.ListItem.view.deviceHeight * 0.7
                                    maxWidth: itemContainer.ListItem.view.deviceWidth * 0.7
                                    scalingMethod: ScalingMethod.AspectFit
                                }
                                Container {
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    verticalAlignment: VerticalAlignment.Top
                                    opacity: 1
                                    background: itemContainer.ListItem.view.background
                                    Label {

                                        text: ListItemData.description
                                        multiline: true
                                        horizontalAlignment: HorizontalAlignment.Center
                                        textStyle{
                                            
                                            fontSize: FontSize.PointValue
                                            fontSizeValue: 10
                                            base: SystemDefaults.TextStyles.TitleText     
                                        }  
                                    }
                                }
                                Container {
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    verticalAlignment: VerticalAlignment.Bottom
                                    bottomPadding: 5
                                    leftPadding: 2
                                    rightPadding: 2
                                    opacity: 1
                                    background: itemContainer.ListItem.view.background
                                    Label {

                                        text: ListItemData.subTitle
                                        multiline: true
                                        horizontalAlignment: HorizontalAlignment.Center
                                        textStyle{
                                            
                                            fontSize: FontSize.PointValue
                                            fontSizeValue:7
                                            base: SystemDefaults.TextStyles.BodyText     
                                        }  
                                    }
                                }
                            }
                        }
                    }
                ]    
            }
        }
    }
}